/*
 * Sixth 3D engine. Copyright ©2012-2018, Svjatoslav Agejenko, svjatoslav@svjatoslav.eu
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 3 of the GNU Lesser General Public License
 * or later as published by the Free Software Foundation.
 *
 */

package eu.svjatoslav.sixth.e3d.renderer.raster.shapes.composite.wireframe;

import eu.svjatoslav.sixth.e3d.geometry.Point3D;
import eu.svjatoslav.sixth.e3d.geometry.Rectangle;
import eu.svjatoslav.sixth.e3d.geometry.Transform;
import eu.svjatoslav.sixth.e3d.renderer.raster.shapes.basic.line.LineAppearance;
import eu.svjatoslav.sixth.e3d.renderer.raster.shapes.composite.base.AbstractCompositeShape;

public class Grid2D extends AbstractCompositeShape {

    public Grid2D(final Transform transform, final Rectangle rectangle,
                  final int divisionsX, final int divisionsY,
                  final LineAppearance appearance) {

        super(transform);

        final double stepY = rectangle.getHeight() / divisionsY;
        final double stepX = rectangle.getWidth() / divisionsX;

        for (int yslice = 0; yslice <= divisionsY; yslice++) {
            final double y = (yslice * stepY) + rectangle.getLowerY();

            for (int xslice = 0; xslice <= divisionsX; xslice++) {
                final double x = (xslice * stepX) + rectangle.getLowerX();

                final Point3D p1 = new Point3D(x, y, 0);
                final Point3D p2 = new Point3D(x + stepX, y, 0);
                final Point3D p3 = new Point3D(x, y + stepY, 0);

                if (xslice < divisionsX)
                    addShape(appearance.getLine(p1, p2));

                if (yslice < divisionsY)
                    addShape(appearance.getLine(p1, p3));
            }

        }

    }

}
